import request from '@/utils/request'

// 查询疫情防控-任务排班列表
export function listYqTask(query) {
  return request({
    url: '/yiqing/yqTask/list',
    method: 'get',
    params: query
  })
}

// 查询疫情防控-任务排班详细
export function getYqTask(yqTaskId) {
  return request({
    url: '/yiqing/yqTask/' + yqTaskId,
    method: 'get'
  })
}

// 新增疫情防控-任务排班
export function addYqTask(data) {
  return request({
    url: '/yiqing/yqTask',
    method: 'post',
    data: data
  })
}

// 修改疫情防控-任务排班
export function updateYqTask(data) {
  return request({
    url: '/yiqing/yqTask',
    method: 'put',
    data: data
  })
}

// 删除疫情防控-任务排班
export function delYqTask(yqTaskId) {
  return request({
    url: '/yiqing/yqTask/' + yqTaskId,
    method: 'delete'
  })
}

// 导出疫情防控-任务排班
export function exportYqTask(query) {
  return request({
    url: '/yiqing/yqTask/export',
    method: 'get',
    params: query
  })
}

// 查询任务提醒规则列表
export function listAllRule() {
  return request({
    url: '/yiqing/rule/listAll',
    method: 'get'
  })
}

// 发布
export function pushTask(taskId) {
  return request({
    url: '/yiqing/yqTask/pushTask?taskId=' + taskId,
    method: 'get'
  })
}
